@@ -279,7 +279,7 @@ static Error ConnectPMtoS(dpgraphstat *index)
     /* select becomes os2_select in arch.h for os2 */
     FD_ZERO (&fdset);
     FD_SET(index->procfd, &fdset);
-    nselect = select (index->procfd + 1, (SelectPtr) &fdset, NULL,NULL,NULL);
+    nselect = select (index->procfd + 1, (SELECT_ARG_TYPE *) &fdset, NULL,NULL,NULL);
     if(nselect > 0) {
         if(_dxf_ExReceiveBuffer(index->procfd, &type, 1, TYPE_INT, 0) < 0) {
             DXUIMessage("ERROR", "bad distributed packet type");
@@ -357,7 +357,7 @@ static Error ConnectPStoS(dpgraphstat *index, dpgraphstat *index2)
     /* wait for a port to accept from */
     FD_ZERO (&fdset);
     FD_SET(index->procfd, &fdset);
-    nselect = select (index->procfd + 1, (SelectPtr) &fdset, NULL,NULL,NULL);
+    nselect = select (index->procfd + 1, (SELECT_ARG_TYPE *) &fdset, NULL,NULL,NULL);
     if(nselect > 0) {
         if(_dxf_ExReceiveBuffer(index->procfd, &type, 1, TYPE_INT,
                                 index->SwapMsg) < 0) {
@@ -382,7 +382,7 @@ static Error ConnectPStoS(dpgraphstat *index, dpgraphstat *index2)
 
             FD_ZERO (&fdset);
             FD_SET(index2->procfd, &fdset);
-            nselect = select (index2->procfd + 1, (SelectPtr) &fdset, 
+            nselect = select (index2->procfd + 1, (SELECT_ARG_TYPE *) &fdset, 
                                                          NULL,NULL,NULL);
             if(nselect > 0) {
                 /* when second slave has connected tell first slave to accept */
@@ -395,7 +395,7 @@ static Error ConnectPStoS(dpgraphstat *index, dpgraphstat *index2)
                     _dxf_SlaveDone();
                     FD_ZERO (&fdset);
                     FD_SET(index2->procfd, &fdset);
-                    nselect = select (index2->procfd + 1, (SelectPtr) &fdset, 
+                    nselect = select (index2->procfd + 1, (SELECT_ARG_TYPE *) &fdset, 
                                       NULL,NULL,NULL);
                     if(nselect <= 0) 
                         goto error_return;
@@ -517,7 +517,7 @@ Error _dxf_ExSlaveListen()
         DXRegisterInputHandler(ExSendModuleInputHandler, dxfd, NULL);
         /* send signature to peer, this must be the first msg that */
         /* the peer gets to determine if it needs to swap bytes    */
-        msgtype = DPMSG_SIGNATURE;
+        msgtype = (DistMsg) DPMSG_SIGNATURE;
         write(dxfd, &msgtype, sizeof(int));  
     }
     else {
@@ -558,7 +558,7 @@ Error _dxf_ExSlaveConnect()
 
     /* connecting as peer to master */
     if(spentry.SlaveId == 0) {
-        msgtype = DPMSG_SIGNATURE;
+        msgtype = (DistMsg) DPMSG_SIGNATURE;
         write(_dxd_exMasterfd, &msgtype, sizeof(int));
         spentry.SwapMsg = _dxd_exSwapMsg;
     }
@@ -575,7 +575,7 @@ Error _dxf_ExSlaveConnect()
 
         /* send signature to peer, this must be the first msg that */
         /* the peer gets to determine if it needs to swap bytes    */
-        msgtype = DPMSG_SIGNATURE;
+        msgtype = (DistMsg) DPMSG_SIGNATURE;
         write(fd, &msgtype, sizeof(int));  
 	
 
