@@ -56,9 +56,6 @@ extern char *sys_errlist[];
 
 
 #include <sys/stat.h> 
-#if ibm6000 
-#include <sys/mode.h> 
-#endif
 
 #if  defined(DXD_NON_UNIX_DIR_SEPARATOR)
 #define DX_DIR_SEPARATOR ';'
@@ -70,25 +67,15 @@ extern char *sys_errlist[];
  * the loaded segment.
  */
 
+#if defined(hp700)
 
-#if ibm6000
-
-#include <sys/ldr.h>
-typedef int (*Handle)();
-#define __HANDLE_DEF
-
-#endif  /* ibm6000 */
-
-#if hp700
-
-#include <dl.h>
-typedef shl_t Handle;
-#define __HANDLE_DEF
+# include <dl.h>
+  typedef shl_t Handle;
+# define __HANDLE_DEF
 
 #endif /* hp700 */
 
-
-#if defined(sun4) || defined(solaris) || defined(sgi) || defined(alphax) || defined(aviion) || defined(linux) || defined(cygwin) || defined(freebsd) || defined(macos)
+#if !defined(hp700) && !defined(intelnt) && !defined(WIN32)
 
 #include <dlfcn.h>
 typedef void *Handle;
@@ -187,27 +174,36 @@ static struct loadtable *set_tp_entry(Ls loadstate,
 static Error findfile(char *inname, char **outname, char *envvar);
 
 
-#if ibm6000
+#if 0 /* ibm6000 */
 
-#define __ROUTINES_DEF
+AIX 4.2 and greater now supports the dl functions. All the specific ibm6000
+loader code is no longer used. How many people are still running AIX 4.1 or 
+lower? Pull an older version of this file from cvs if the older loader code
+is needed. The notes on compilation below need updated.
 
 /* 
  * to make a dynamically loaded module, you have to link with these flags:
  *
- *  -bI:dxexec.exp   this lists the symbols in the exec which your module
+ *  -qmkshrobj       construct a shared object with C++
+ *
+ *  -bI:dxexec.imp   this lists the symbols in the exec which your module
  *                   will be able to call at runtime - like all the libdx
  *                   functions.  otherwise, they will be undefined when 
  *                   trying to link this module independently of the exec.
  *
- * -e _entrypoint    this sets the name of the function which will be returned
- *                   as the entry point - it must be the symbol DXEntry, which
- *                   is a routine generated by the mdf2c script when building
- *                   the module or package of modules.
+ *  -G               same as calling -berok -brtl -bnortllib -bsymbolic 
+ *                   -bnoautoexp -bM:SRE. -berok is definitely needed to
+ *                   ignore the dxexec undefined symbols and -bM:SER for
+ *                   a reentrant library.
  *
- * the exec doesn't have to be linked with any special flags because it
- *  isn't expecting to call any of the subroutines defined in these modules
- *  directly - it is only going to call the single entry point, and it makes
- *  that call by address and not by name.
+ * the exec doesn't have to be linked with any special flags, except to export
+ *  its sybols (see below) because it isn't expecting to call any of the 
+ *  subroutines defined in these modules directly - it is only going to call
+ *  the single entry point, and it makes that call by address and not by name.
+ *  It must export its symbol table so that loaded modules will be able to 
+ *  access dx routines from within the exec.
+ *
+ *  -bE:dxexec.exp
  *
  * if we wanted the exec to be able to call directly into the dynamically
  *  loaded module code by subroutine names, then at link time the exec would
@@ -216,6 +212,8 @@ static Error findfile(char *inname, char **outname, char *envvar);
  *  contained a list of symbol names to be made public.
  */
 
+#endif  /* ibm6000 */
+
 
 #if 0   /* comment */
 
@@ -257,140 +255,6 @@ it worked fine UP.
 
 #endif  /* comment */
 
-    
-
-PFI DXLoadObjFile(char *fname, char *envvar)
-{
-    int (*func)();
-    extern Error DXinitdx(); /* from libdx/init.c */
-    char *foundname = NULL;
-    struct loadtable *lp = NULL;
-
-    DXDebug("L", "trying to load `%s'", fname);
-    if (!findfile(fname, &foundname, envvar)) 
-	return NULL;
-
-    if (!DXlock(ltl, 0))
-	return NULL;
-
-    DXDebug("L", "found at `%s'", foundname);
-    if (((lp = get_tp_entry(foundname)) != NULL) && 
-	 (lp->loadstate == L_LOADED)) {
-	DXDebug("L", "`%s' was already loaded", foundname);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return ALREADY_LOADED;
-    }
-
-    DXDebug("L", "ready to call load");
-    func = load(foundname, L_NOAUTODEFER, "."); 
-    /* func = loadAndInit(foundname, L_NOAUTODEFER, "."); */
-    if (func == NULL) {
-	DXSetError(ERROR_DATA_INVALID, 
-		   "cannot load file `%s', %s", foundname, sys_errlist[errno]);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return NULL;
-    }
-    
-    DXDebug("L", "ready to call loadbind");
-    if (loadbind(0, (void *)DXinitdx, (void *)func) < 0) {
-	DXSetError(ERROR_DATA_INVALID, 
-		   "cannot resolve symbols in file `%s', %s", 
-		   fname, sys_errlist[errno]);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return NULL;
-    }
-    
-    DXDebug("L", "setting tp entry for `%s'", foundname);
-    if (!set_tp_entry(L_LOADED, foundname, func, func)) {
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return NULL;
-    }
-    DXDebug("L", "tp entry now set for `%s'", foundname);
-
-    DXFree((Pointer)foundname);
-    DXunlock(ltl, 0);
-    return func;
-}
-
-Error DXLoadAndRunObjFile(char *fname, char *envvar)
-{
-    int (*func)();
-    
-    func = DXLoadObjFile(fname, envvar);
-    if (func == NULL)
-	return ERROR;
-    if (func == ALREADY_LOADED)
-	return OK;
-
-    if (DXQueryDebug("L"))
-        DXEnableDebug("F", 1);
-	
-    (*func)();
-    
-    if (DXQueryDebug("L"))
-        DXEnableDebug("F", 1);
-	
-    if (DXGetError() != ERROR_NONE)
-	return ERROR;
-
-    return OK;
-}
-
-
-Error DXUnloadObjFile(char *fname, char *envvar)
-{
-    char *foundname = NULL;
-    struct loadtable *lp = NULL;
-
-    if (!findfile(fname, &foundname, envvar))
-	return ERROR;
-    
-    if (!DXlock(ltl, 0))
-	return NULL;
-
-    if (((lp = get_tp_entry(foundname)) != NULL) && 
-	(lp->loadstate == L_UNLOADED)) {
-	DXDebug("L", "`%s' found but already unloaded", foundname);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return OK;
-    }
-    
-    if (!lp) {
-	DXDebug("L", "`%s' not found in load list", foundname);
-	DXSetError(ERROR_BAD_PARAMETER, 
-		   "cannot unload `%s'; not found in load list", foundname);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return OK;
-    }
-
-    if (unload((void *)lp->h) < 0) { 
-    /* if (terminateAndUnload((void *)lp->h) < 0) { */
-	DXSetError(ERROR_DATA_INVALID, "cannot unload file '%s', %s", 
-		   foundname, sys_errlist[errno]);
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return ERROR;
-    }
-    
-    if (!set_tp_entry(L_UNLOADED, foundname, (Handle)0, (EntryPt)0)) {
-	DXFree((Pointer)foundname);
-	DXunlock(ltl, 0);
-	return ERROR;
-    }
-    
-    DXFree((Pointer)foundname);
-    DXunlock(ltl, 0);
-    return OK;
-}
-
-#endif  /* ibm6000 */
-
 
 #if hp700
 
@@ -571,8 +435,7 @@ Error DXUnloadObjFile(char *fname, char *envvar)
 #endif  /* hp700 */
 
 
-#if defined(sun4) || defined(solaris) || defined(sgi) || defined(alphax) || defined(aviion) || defined(linux) || defined(cygwin) || defined(freebsd) || defined(macos)
-
+#if !defined(hp700) && !defined(intelnt) && !defined(WIN32)
 
 #define __ROUTINES_DEF
 
@@ -616,7 +479,7 @@ PFI DXLoadObjFile(char *fname, char *envvar)
      *  filename, mode.  the mode is: RTLD_LAZY (defer binding of procs)
      *  other vals are reserved for future expansion.
      */
-    handle = dlopen(foundname, RTLD_LAZY);
+    handle = dlopen(foundname, RTLD_LAZY|RTLD_GLOBAL);
     if (handle == NULL) {
 	char *cp = dlerror();
 	if (cp)
@@ -711,7 +574,7 @@ Error DXUnloadObjFile(char *fname, char *envvar)
 
 #endif  /* sun4, etc */
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
 
 #define __ROUTINES_DEF	1
 
@@ -803,15 +666,66 @@ Error DXLoadAndRunObjFile(char *fname, char *envvar)
 
     return OK;
 }
+
 Error DXUnloadObjFile(char *fname, char *envvar)
 {
+    char *foundname = NULL;
+    struct loadtable *lp = NULL;
+
+    if (!findfile(fname, &foundname, envvar))
+        return ERROR;
+
+    if (((lp = get_tp_entry(foundname)) != NULL) && 
+        (lp->loadstate == L_UNLOADED)) {
+            DXDebug("L", "`%s' found but already unloaded", foundname);
+            DXFree((Pointer)foundname);
+            return OK;
+    }
+
+    if (!lp) {
+        DXDebug("L", "`%s' not found in load list", foundname);
+        DXSetError(ERROR_BAD_PARAMETER, 
+            "cannot unload `%s'; not found in load list", foundname);
+        DXFree((Pointer)foundname);
+        return OK;
+    }
+    
+    if (! FreeLibrary((HMODULE)lp->h)) {
+        DXSetError(ERROR_INVALID_DATA, "cannot unload file '%s', %s", 
+            foundname, sys_errlist[errno]);
+        DXFree((Pointer)foundname);
+        return ERROR;
+    }
+    
+    if (!set_tp_entry(L_UNLOADED, foundname, (Handle)0, (EntryPt)0)) {
+        DXFree((Pointer)foundname);
+        return ERROR;
+    }
+
+    DXFree((Pointer)foundname);
     return OK;
 }
 
 
+#if defined(DX_NATIVE_WINDOWS)
+
+void
+DXFreeLoadedObjectFiles()
+{
+    struct loadtable *np;
+
+	while ((np = ltp[DXProcessorId()]) != NULL)
+	{
+		FreeLibrary((HMODULE)np->h);
+		ltp[DXProcessorId()] = np->next;
+		DXFree((Pointer)np);
+	}
+}
+
+#endif   /* DX_NATIVE_WINDOWS */
 
 
-#endif   /*   DXD_WIN     */
+#endif   /*   DXD_WIN         */
 
 
 
