@@ -320,9 +320,10 @@ Reg_InitVectorPart(Field f, Reg_VectorGrp P, int flag)
     {
 	ip->invElements = DXCreateInvalidComponentHandle((Object)f,
 						    NULL, "connections");
-	if (! ip->invElements)
-	fprintf(stderr, "Reg_InitVectorPart error 10\n");
+	if (! ip->invElements) {
+	    fprintf(stderr, "Reg_InitVectorPart error 10\n");
 	    goto error;
+	}
     }
     else
 	ip->invElements = NULL;
@@ -775,9 +776,9 @@ Reg_FaceWeights(InstanceVars I, POINT_TYPE *pt)
 	double D  = dx * dy * dz;
 
 	{
-	    double aa, bb;
+	    double aa;
 	    aa = (1.0 + A + B + C) - (dz + dy + dx + D);
-	    bb = 1.0 - dz - dy - dx + A + B + C - D;
+	    /*bb = 1.0 - dz - dy - dx + A + B + C - D;*/
 	    *w++ = aa;
 	}
 
