@@ -8,12 +8,11 @@
 
 #include <dxconfig.h>
 
-
 #include <stdio.h>
 #include <dx/dx.h>
 #include "import.h"
 
-#if defined(WIN32) && defined(NDEBUG)
+#if (defined(WIN32) && defined(NDEBUG)) || defined(_MT)
 #define _HDFDLL_
 #elif defined(_DEBUG)
 #undef _DEBUG
@@ -25,19 +24,55 @@
 #define UNIX386
 #endif
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
 #define F_OK	0
 #define R_OK	4
 #define INTEL86 
 #endif
 
+/* hdfi.h typdefs a set of number types whereas dx defines them
+   with configure. In order to compile, it is necessary for us to
+   undef them so the hdfi.h header can be included. 
+ */
+ 
+#if !defined(intelnt) && !defined(WIN32)
+
+#ifdef int8
+#undef int8
+#endif
+#ifdef uint8
+#undef uint8
+#endif
+#ifdef int16
+#undef int16
+#endif
+#ifdef uint16
+#undef uint16
+#endif
+#ifdef int32
+#undef int32
+#endif
+#ifdef uint32
+#undef uint32
+#endif
+#ifdef float32
+#undef float32
+#endif
+#ifdef float64
+#undef float64
+#endif
+
+#endif
+
 #if defined(HAVE_DFSD_H)
 #include <dfsd.h>
 #else
 #include <hdf/dfsd.h>
 #endif
 
+#if !defined(macos)
 #include <ctype.h>
+#endif
 
 /* special access: needs extra include file, and has different constants 
  *  to call stat() to find out if file exists and is readable.
