@@ -146,6 +146,12 @@ static Error  PickInterpolate(Object, Field, int);
 #define CLOSEST_VERTEX  1
 #define INTERPOLATE     2
 
+/*
+ * Used only by StereoPick
+ */
+#define STEREO_ARG      9
+#define WHERE_ARG       10
+
 static Array getXY(Array);
 
 Error
@@ -169,9 +175,6 @@ m_Pick(Object *in, Object *out)
     int      persistence;
     int	     first;
     int      interpolate = NO_INTERP;
-#if 0
-    int	     autoaxes = 0;
-#endif
 
     pick.picks     = NULL;
     pick.paths     = NULL;
@@ -231,20 +234,6 @@ m_Pick(Object *in, Object *out)
 	    }
 	}
 
-
-#if 0
-	if (NULL != (attr = DXGetAttribute(object, "autoaxes")))
-	{
-	    if (! DXExtractInteger(attr, &autoaxes) || autoaxes != 1)
-	    {
-		DXSetError(ERROR_INTERNAL, "invalid attribute: autoaxes flag");
-		goto error;
-	    }
-	}
-	else
-	    autoaxes = 0;
-#endif
-
 	list = (Array)in[LIST_ARG];
 	if (list)
 	{
@@ -294,21 +283,7 @@ m_Pick(Object *in, Object *out)
 
 	    sensitivity = SENSITIVITY;
 
-#if 0
-	    if (autoaxes)
-	    {
-		Matrix m;
-
-		if (! GetAAMatrix(object, &m))
-		    goto error;
-
-		initialMatrix = DXConcatenate(m, cameraMatrix);
-	    }
-	    else
-		initialMatrix = cameraMatrix;
-#else
 	    initialMatrix = cameraMatrix;
-#endif
 	
 
 	    xy = xyPicks;
@@ -490,30 +465,7 @@ m_Pick(Object *in, Object *out)
 
 	object = in[OBJECT_ARG];
 	if (! object)
-	{
 	    object = cacheObject;
-#if 0
-	    autoaxes = 0;
-#endif
-	}
-#if 0
-	else 
-	{
-	    Object attr;
-
-	    if (cacheObject && 
-		 (NULL != (attr = DXGetAttribute(cacheObject, "autoaxes"))))
-	    {
-		if (! DXExtractInteger(attr, &autoaxes) || autoaxes != 1)
-		{
-		    DXSetError(ERROR_INTERNAL, "invalid attribute: autoaxes flag");
-		    goto error;
-		}
-	    }
-	    else
-		autoaxes = 0;
-	}
-#endif
 
 	list = (Array)in[LIST_ARG];
 	
@@ -564,22 +516,7 @@ m_Pick(Object *in, Object *out)
 
 	    sensitivity = SENSITIVITY;
 
-#if 0
-	    if (autoaxes)
-	    {
-		Matrix m;
-
-		if (! GetAAMatrix(cacheObject, &m))
-		    goto error;
-
-		initialMatrix = DXConcatenate(m, cameraMatrix);
-	    }
-	    else
-		initialMatrix = cameraMatrix;
-#else
 	    initialMatrix = cameraMatrix;
-#endif
-	
 
 	    xy = xyPicks;
 	    for (i = 0; i < nPicks; i++, xy ++)
@@ -725,6 +662,74 @@ error:
     return ERROR;
 }
 
+extern Error _dxfGetStereoCameras(void *, Camera, Camera *, Camera *);
+extern void *_dxfGetStereoWindowInfo(char *, void *, void *);
+
+m_StereoPick(Object *in, Object *out)
+{
+    Camera camera, lcamera, rcamera;
+    char *where;
+    void *globals;
+
+    out[0] = NULL;
+
+    if (! in[LIST_ARG])
+        return OK;
+
+    in[LIST_ARG] = (Object)getXY((Array)in[LIST_ARG]);
+    if (! in[LIST_ARG])
+        return OK;
+
+    if (! in[STEREO_ARG])
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "stereo arg must be given");
+        return ERROR;
+    }
+
+    if (! in[WHERE_ARG] || ! DXExtractString(in[WHERE_ARG], &where))
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "where must be given");
+        return ERROR;
+    }
+
+    if (! _dxfLoadStereoModes())
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "error loading stereo code");
+        return ERROR;
+    }
+
+    globals = _dxfGetStereoWindowInfo(where, NULL, NULL);
+    if (! globals)
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "error accessing stereo window info");
+        return ERROR;
+    }
+
+    if (! in[CAMERA_ARG])
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "camera arg must be given");
+        return ERROR;
+    }
+
+    camera = (Camera)in[CAMERA_ARG];
+
+    _dxfLoadStereoModes();
+
+    if (! _dxfInitializeStereoCameraMode(globals, in[STEREO_ARG]))
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "error initting stereo mode");
+        return ERROR;
+    }
+
+    if (! _dxfGetStereoCameras(globals, camera, &lcamera, &rcamera))
+    {
+        DXSetError(ERROR_BAD_PARAMETER, "error getting stereo cameras");
+        return ERROR;
+    }
+
+    return m_Pick(in, out);
+}
+
 static Field
 GetPicksFromCache(char *tag, Object *in)
 {
@@ -832,7 +837,7 @@ PickBufToField(PickBuf *p, Matrix m)
     int   *pokPtr;
     int   *idxPtr;
     int   *pathSrc, *pathDst;
-    int   i, j, k, lastPoke;
+    int   i, j, lastPoke;
 
     if (p->picks == NULL)
         return DXNewField();
@@ -878,7 +883,7 @@ PickBufToField(PickBuf *p, Matrix m)
     pathDst = (int   *)DXGetArrayData(paths);
 
     lastPoke = -1;
-    for (i = j = k = 0; i < nPicks; i++, picks ++)
+    for (i = j = 0; i < nPicks; i++, picks ++)
     {
 	*posPtr++ = DXApply(picks->xyz, m);
 	*idxPtr++ = j;
@@ -1556,11 +1561,11 @@ Elt2D_Perspective(PickBuf *p, int poke, Point2D xy, Point *xPoints, int *elts,
 	    {
 		Point   *lxp = xPoints + last;
 		Point   *nxp = xPoints + next;
-		float   x, y, z, d = (nearPlane - lxp->z) / (nxp->z - lxp->z);
+		float   x, y, d = (nearPlane - lxp->z) / (nxp->z - lxp->z);
 
 		x = lxp->x + d*(nxp->x - lxp->x);
 		y = lxp->y + d*(nxp->y - lxp->y);
-		z = nearPlane;
+		/* z = nearPlane; */
 		
 		sclippt[nclip].x = dNear * x;
 		sclippt[nclip].y = dNear * y;
@@ -1893,9 +1898,8 @@ Elt1D_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
     for (i = 0; i < nElts; i++, elts += 2)
     {
 	int     p, q;
-	Point   *px, *qx, *xclipped[2];
+	Point   *px, *qx;
 	Point   *ps, *qs, *sclipped[2];
-	Point   xclippt;
 	Point   sclippt;
 	float   x, y, z, a, b, c, D, dx, dy, depth;
 	Point   xyz;
@@ -1915,8 +1919,8 @@ Elt1D_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	
 	if (px->z <= nearPlane && qx->z <= nearPlane)
 	{
-	    xclipped[0] = px;
-	    xclipped[1] = qx;
+	    /*xclipped[0] = px;*/
+	    /*xclipped[1] = qx;*/
 
 	    sclipped[0] = ps;
 	    sclipped[1] = qs;
@@ -1928,11 +1932,11 @@ Elt1D_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	{
 	    float d = (nearPlane - qx->z) / (px->z - qx->z);
 
-	    xclippt.x = qx->x + d*(px->x - qx->x);
-	    xclippt.y = qx->y + d*(px->y - qx->y);
-	    xclippt.z = nearPlane;
-	    xclipped[0] = &xclippt;
-	    xclipped[1] = qx;
+	    /*xclippt.x = qx->x + d*(px->x - qx->x);*/
+	    /*xclippt.y = qx->y + d*(px->y - qx->y);*/
+	    /*xclippt.z = nearPlane;*/
+	    /*xclipped[0] = &xclippt;*/
+	    /*xclipped[1] = qx;*/
 
 	    sclippt.x = qs->x + d*(ps->x - qs->x);
 	    sclippt.y = qs->y + d*(ps->y - qs->y);
@@ -1947,11 +1951,11 @@ Elt1D_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	{
 	    float d = (nearPlane - qx->z) / (px->z - qx->z);
 
-	    xclippt.x = qx->x + d*(px->x - qx->x);
-	    xclippt.y = qx->y + d*(px->y - qx->y);
-	    xclippt.z = nearPlane;
-	    xclipped[0] = &xclippt;
-	    xclipped[1] = px;
+	    /*xclippt.x = qx->x + d*(px->x - qx->x);*/
+	    /*xclippt.y = qx->y + d*(px->y - qx->y);*/
+	    /*xclippt.z = nearPlane;*/
+	    /*xclipped[0] = &xclippt;*/
+	    /*xclipped[1] = px;*/
 
 	    sclippt.x = qs->x + d*(ps->x - qs->x);
 	    sclippt.y = qs->y + d*(ps->y - qs->y);
@@ -2300,9 +2304,8 @@ Polyline_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	for (e = estart, eIndex = 0; e < eend; e++, eIndex++)
 	{
 	    int     p, q;
-	    Point   *px, *qx, *xclipped[2];
+	    Point   *px, *qx;
 	    Point   *ps, *qs, *sclipped[2];
-	    Point   xclippt;
 	    Point   sclippt;
 	    float   x, y, z, a, b, c, D, dx, dy, depth;
 	    Point   xyz;
@@ -2322,8 +2325,8 @@ Polyline_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	
 	    if (px->z <= nearPlane && qx->z <= nearPlane)
 	    {
-		xclipped[0] = px;
-		xclipped[1] = qx;
+		/*xclipped[0] = px;*/
+		/*xclipped[1] = qx;*/
 
 		sclipped[0] = ps;
 		sclipped[1] = qs;
@@ -2335,11 +2338,11 @@ Polyline_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	    {
 		float d = (nearPlane - qx->z) / (px->z - qx->z);
 
-		xclippt.x = qx->x + d*(px->x - qx->x);
-		xclippt.y = qx->y + d*(px->y - qx->y);
-		xclippt.z = nearPlane;
-		xclipped[0] = &xclippt;
-		xclipped[1] = qx;
+		/*xclippt.x = qx->x + d*(px->x - qx->x);*/
+		/*xclippt.y = qx->y + d*(px->y - qx->y);*/
+		/*xclippt.z = nearPlane;*/
+		/*xclipped[0] = &xclippt;*/
+		/*xclipped[1] = qx;*/
 
 		sclippt.x = qs->x + d*(ps->x - qs->x);
 		sclippt.y = qs->y + d*(ps->y - qs->y);
@@ -2354,11 +2357,11 @@ Polyline_Perspective(PickBuf *pick, int poke, Point2D xy, Point *xPoints,
 	    {
 		float d = (nearPlane - qx->z) / (px->z - qx->z);
 
-		xclippt.x = qx->x + d*(px->x - qx->x);
-		xclippt.y = qx->y + d*(px->y - qx->y);
-		xclippt.z = nearPlane;
-		xclipped[0] = &xclippt;
-		xclipped[1] = px;
+		/*xclippt.x = qx->x + d*(px->x - qx->x);*/
+		/*xclippt.y = qx->y + d*(px->y - qx->y);*/
+		/*xclippt.z = nearPlane;*/
+		/*xclipped[0] = &xclippt;*/
+		/*xclipped[1] = px;*/
 
 		sclippt.x = qs->x + d*(ps->x - qs->x);
 		sclippt.y = qs->y + d*(ps->y - qs->y);
