@@ -10,7 +10,7 @@
 
 
 /*
- * $Header: /src/master/dx/src/exec/dxmods/streakline.c,v 1.5 2000/08/24 20:04:51 davidt Exp $:
+ * $Header: /src/master/dx/src/exec/dxmods/streakline.c,v 1.7 2002/03/21 02:57:40 rhh Exp $:
  */
 #include <dx/dx.h>
 #include "stream.h"
@@ -758,7 +758,7 @@ Streakline(CacheObject cstreak,	/* accumulated streak info		*/
     double     	 t, t2;
     int		 done, keepPoint;
     Field 	 field = NULL;
-    int 	 i, totKnt, zeroKnt;
+    int 	 i, totKnt;
     StreakFlags  sFlag;
     StreakVars   svars;
     int		 zeroVector;
@@ -836,7 +836,7 @@ Streakline(CacheObject cstreak,	/* accumulated streak info		*/
     /*
      * While streak is passing from partition to partition...
      */
-    done = 0; totKnt = 1; zeroKnt = 0;
+    done = 0; totKnt = 1;
     while (!done)
     {
 	zeroVector = ZeroVector(v0, nDim);
@@ -2494,7 +2494,7 @@ GetFrameData(Object vectors, Object curls, CacheObject co)
 	    goto error;
 	}
 
-	co->v1 = DXCopy(co->v1, COPY_STRUCTURE);
+	co->v1 = DXReference(DXCopy(co->v1, COPY_STRUCTURE));
 	if (! co->v1)
 	    goto error;
 	
@@ -2534,7 +2534,7 @@ GetFrameData(Object vectors, Object curls, CacheObject co)
 	    goto error;
 	}
 
-	co->v1 = DXCopy(vectors, COPY_STRUCTURE);
+	co->v1 = DXReference(DXCopy(vectors, COPY_STRUCTURE));
 	if (! co->v1)
 	    goto error;
 	
