@@ -10,13 +10,13 @@
 
 #include "trace.h"
 
-#if 0
+#if defined(WIN32)
 #include <dx/dx.h>
 
 Error 
 DXVisualizeMemory(int which, int procid)
 {
-    DXMessage("visual memory display only available in debuggable version of system");
+    DXMessage("visual memory display only available in X11 version of DX.");
     return OK;
 }
 
@@ -101,7 +101,7 @@ struct dispinfo {
     int pixel_ymult;		/* real pixels along each each of virtual p */
     int alloc_unit;		/* minimum arena allocation size in bytes */
     Pointer arena_base;		/* first address in this arena */
-    uint arena_size;		/* arena size in bytes (-1 = uninitialized) */
+    ulong arena_size;		/* arena size in bytes (-1 = uninitialized) */
     int which;			/* which arena */
     int nproc;			/* for local, which processor */
     int smallsize;              /* color smaller blocks differently */
@@ -127,7 +127,7 @@ static struct dispinfo *d_local[32] = { NULL };
 /* prototypes */
 
 static void init_dispinfo(struct dispinfo *d);
-static void pix_set(struct dispinfo *d, Pointer start, uint size, ubyte color);
+static void pix_set(struct dispinfo *d, Pointer start, ulong size, ubyte color);
 static Error report_memory(struct dispinfo *d);
 static Error query_memory(struct dispinfo *d);
 static Display *open_memory_visual_display();
@@ -135,11 +135,11 @@ static Error init_memory_visual (struct dispinfo *d);
 static void cleanup_memory_visual (struct dispinfo *d);
 static int error_handler(Display *dpy, XErrorEvent *event);
 static Error handler_script(int fd, struct dispinfo *d);
-static Error memsee(int blocktype, Pointer start, uint size, Pointer p);
-static Error memsee1(int blocktype, Pointer start, uint size, Pointer p);
-static Error memquery(int blocktype, Pointer start, uint size, Pointer p);
+static Error memsee(int blocktype, Pointer start, ulong size, Pointer p);
+static Error memsee1(int blocktype, Pointer start, ulong size, Pointer p);
+static Error memquery(int blocktype, Pointer start, ulong size, Pointer p);
 
-void sigcatch();
+void _dxf_sigcatch();
 #define NSECONDS 2    /* automatic update */
 
 
@@ -176,7 +176,6 @@ DXVisualizeMemory(int which, int procid)
 		return ERROR;
 	    
 	    if (DXGetMemorySize(&d_small->arena_size, NULL, NULL)
-		&& d_small->arena_size >= 0
 		&& DXGetMemoryBase(&d_small->arena_base, NULL, NULL)) {
 
 		d_small->which = MEMORY_SMALL;
@@ -208,7 +207,6 @@ DXVisualizeMemory(int which, int procid)
 	    
 	    
 	    if (DXGetMemorySize(NULL, &d_large->arena_size, NULL) 
-		&& d_large->arena_size >= 0
 		&& DXGetMemoryBase(NULL, &d_large->arena_base, NULL)) {
 	
 		d_large->which = MEMORY_LARGE;
@@ -235,8 +233,9 @@ DXVisualizeMemory(int which, int procid)
     }
 
     if (which & 4) {			/* local memory */
+	ulong local_size;
 
-	if (!DXGetMemorySize(NULL, NULL, &i) || i == 0) {
+	if (!DXGetMemorySize(NULL, NULL, &local_size) || local_size == 0) {
 	    DXSetError(ERROR_DATA_INVALID, "local memory not supported");
 	    return ERROR;
 	}
@@ -302,7 +301,7 @@ DXVisualizeMemory(int which, int procid)
 	    report_memory(d_local[i]);
 
 #if !defined(intelnt)
-    signal(SIGALRM, sigcatch);
+    signal(SIGALRM, _dxf_sigcatch);
     alarm(NSECONDS);    
 #endif
     return OK;
@@ -313,7 +312,7 @@ static void
 init_dispinfo(struct dispinfo *d)
 {
     int total_squares;
-    uint h;
+    ulong h;
 
     d->win_width = WIN_WIDTH;
     d->win_height = WIN_HEIGHT;
@@ -387,7 +386,7 @@ resize_display(struct dispinfo *d, int new_width, int new_height)
 
     d->memory_image = XCreateImage(d->disp,
 			     XDefaultVisual(d->disp, XDefaultScreen(d->disp)),
-			     8, ZPixmap, 0, d->memory_pixel,
+			     8, ZPixmap, 0, (char *) d->memory_pixel,
 			     d->win_width, d->win_height, 8, 0);
 
     XResizeWindow(d->disp, d->wind, d->win_width, d->win_height);
@@ -396,16 +395,17 @@ resize_display(struct dispinfo *d, int new_width, int new_height)
 }
 
 static void 
-pix_set(struct dispinfo *d, Pointer memstart, uint memsize, ubyte color)
+pix_set(struct dispinfo *d, Pointer memstart, ulong memsize, ubyte color)
 {
-    int start, size;			/* start, num to set in 'squares' */
-    int row, col;			/* window column, row to set */
-    int part;				/* wrap around edge of window */
-    uint where;
+    ulong start, size;			/* start, num to set in 'squares' */
+    ulong row, col;			/* window column, row to set */
+    ulong part;				/* wrap around edge of window */
+    ulong where;
     int i;
 
     /* round size up.  is start also off by one? */
-    start = (((ubyte *)memstart) - ((ubyte *)d->arena_base))/d->bytes_vp * d->pixel_xmult;
+    start = (((ubyte *)memstart) - 
+	     ((ubyte *)d->arena_base))/d->bytes_vp * d->pixel_xmult;
     size = DivideRoundedUp(memsize, d->bytes_vp) * d->pixel_xmult;
 
     col = start % d->win_width;
@@ -420,13 +420,13 @@ pix_set(struct dispinfo *d, Pointer memstart, uint memsize, ubyte color)
 
 	for (i=0; i < d->pixel_ymult; i++) {
 	    
-	    where = (uint)d->memory_pixel + (row + i) * d->win_width + col;
-	    if (where >= (uint)d->memory_pixel + WinSize(d))
+	    where = (ulong)d->memory_pixel + (row + i) * d->win_width + col;
+	    if (where >= (ulong)d->memory_pixel + WinSize(d))
 		break;
 	    
-	    if ((where + part) >= (uint)d->memory_pixel + WinSize(d))
+	    if ((where + part) >= (ulong)d->memory_pixel + WinSize(d))
 		part -= (where + part) - 
-		    ((uint)d->memory_pixel + WinSize(d) + 1);
+		    ((ulong)d->memory_pixel + WinSize(d) + 1);
 
 	    memset ((ubyte *)where, color, part);
 	}
@@ -441,14 +441,14 @@ pix_set(struct dispinfo *d, Pointer memstart, uint memsize, ubyte color)
 
 /* turn on pixels corresponding to this memory range */
 static Error 
-memsee(int blocktype, Pointer start, unsigned int size, Pointer p)
+memsee(int blocktype, Pointer start, ulong size, Pointer p)
 {
     pix_set((struct dispinfo *)p, start, size, color_alloc);
     return OK;
 }
 
 static Error 
-memsee1(int blocktype, Pointer start, unsigned int size, Pointer p)
+memsee1(int blocktype, Pointer start, ulong size, Pointer p)
 {
     if (size >= ((struct dispinfo *)p)->smallsize)
 	return OK;
@@ -459,7 +459,7 @@ memsee1(int blocktype, Pointer start, unsigned int size, Pointer p)
 
 /* check to see if this block is in the query range */
 static Error 
-memquery(int blocktype, Pointer start, unsigned int size, Pointer p)
+memquery(int blocktype, Pointer start, ulong size, Pointer p)
 {
     struct dispinfo *d = (struct dispinfo *)p;
     Pointer end = (Pointer)(((ubyte *)start) + size);
@@ -663,15 +663,15 @@ init_memory_visual (struct dispinfo *d)
     d->gc = XCreateGC (d->disp, d->wind, flags, &val);
 
     XAllocNamedColor (d->disp, colors, COLOR_ALLOC, &shade, &exact);
-    color_alloc = shade.pixel;
+    color_alloc = (ubyte) shade.pixel;
     XAllocNamedColor (d->disp, colors, COLOR_SMALLOC, &shade, &exact);
-    color_smallalloc = shade.pixel;
+    color_smallalloc = (ubyte) shade.pixel;
     XAllocNamedColor (d->disp, colors, COLOR_FREE, &shade, &exact);
-    color_free = shade.pixel;
+    color_free = (ubyte) shade.pixel;
     XAllocNamedColor (d->disp, colors, COLOR_TRACE, &shade, &exact);
-    color_trace = shade.pixel;
+    color_trace = (ubyte) shade.pixel;
     XAllocNamedColor (d->disp, colors, COLOR_EXTRA, &shade, &exact);
-    color_extra = shade.pixel;
+    color_extra = (ubyte) shade.pixel;
 
 
     d->memory_pixel = (ubyte *) DXAllocate(w * h);
@@ -679,7 +679,8 @@ init_memory_visual (struct dispinfo *d)
 
     d->memory_image = XCreateImage (d->disp,
 			   XDefaultVisual (d->disp, XDefaultScreen (d->disp)),
-			   8, ZPixmap, 0, d->memory_pixel, w, h, 8, 0);
+			   8, ZPixmap, 0, (char *) d->memory_pixel, 
+			   w, h, 8, 0);
     
     XSetErrorHandler(error_handler);
 
@@ -882,7 +883,7 @@ error:
 }
 
 
-void sigcatch()
+void _dxf_sigcatch()
 {
     if (d_small)
 	report_memory(d_small);
@@ -892,10 +893,10 @@ void sigcatch()
     
 
 #if !defined(intelnt)
-    signal(SIGALRM, sigcatch);
+    signal(SIGALRM, _dxf_sigcatch);
     alarm(NSECONDS);
 #endif
 }
 
-#endif   /* 1 */
+#endif   /* !(WIN32) */
 
