@@ -7,12 +7,12 @@
 /***********************************************************************/
 
 #include <dxconfig.h>
-#include "hwDeclarations.h"
+#include "../hwDeclarations.h"
 
 #ifndef HELPERCODE
 
 /*---------------------------------------------------------------------------*\
-$Header: /src/master/dx/src/exec/hwrender/opengl/hwPortUtilOGL.c,v 1.6 2000/10/06 05:04:37 davidt Exp $
+$Header: /src/master/dx/src/exec/hwrender/opengl/hwPortUtilOGL.c,v 1.13 2003/09/30 17:41:45 davidt Exp $
 
 Author:  Ellen Ball
 
@@ -21,6 +21,7 @@ Based on hwrender/gl/hwPortUtil.c
 \*---------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <string.h>
 
 #ifdef DEBUG
 #define TIMER(s) glFlush(); DXMarkTime(s);
@@ -28,15 +29,16 @@ Based on hwrender/gl/hwPortUtil.c
 #define TIMER(s)
 #endif
 
-#include "hwXfield.h"
-#include "hwWindow.h"
-#include "hwPortLayer.h"
+#include "../hwXfield.h"
+#include "../hwWindow.h"
+#include "../hwPortLayer.h"
+#include "../hwTmesh.h"
+#include "../hwObjectHash.h"
+#include "../hwSort.h"
 #include "hwPortOGL.h"
-#include "hwTmesh.h"
-#include "hwObjectHash.h"
-#include "hwSort.h"
 
-#include "hwDebug.h"
+
+#include "../hwDebug.h"
 
 #if defined(HAVE_WINDOWS_H)
 #include <windows.h>
@@ -47,9 +49,10 @@ Based on hwrender/gl/hwPortUtil.c
 #endif
 
 #include <GL/gl.h>
+#include <GL/glu.h>
 
 static void loadTexture(xfieldP);
-static void startTexture();
+static void startTexture(xfieldP);
 static void endTexture();
 
 static int doesTrans;
@@ -74,22 +77,36 @@ static GLubyte screen_door_50[] =
   0xAA, 0xAA, 0xAA, 0xAA, 0x55, 0x55, 0x55, 0x55
 } ;
 
+
+#define LightModel(xf) \
+   do {                                                   \
+     if(xf->attributes.light_model == lm_two_side)        \
+        glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE);  \
+     else                                                 \
+        glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE); \
+   }                                                      \
+   while (0)
+
 #define Cull(xf)                       \
-   if(xf->cullFace == DXHW_CULL_BACK)  \
+   if(xf->attributes.cull_face == cf_back)  \
    {                                   \
       glEnable(GL_CULL_FACE);          \
       glCullFace(GL_BACK);             \
    }                                   \
    else                                \
-   if(xf->cullFace == DXHW_CULL_FRONT) \
+   if(xf->attributes.cull_face == cf_front) \
    {                                   \
       glEnable(GL_CULL_FACE);          \
       glCullFace(GL_FRONT);            \
    }                                   \
    else                                \
-   if(xf->cullFace != DXHW_CULL_OFF)   \
-      glDisable(GL_CULL_FACE);         \
-
+   if(xf->attributes.cull_face == cf_front_and_back) \
+   {                                   \
+      glEnable(GL_CULL_FACE);          \
+      glCullFace(GL_FRONT_AND_BACK);   \
+   }                                   \
+   else                                \
+      glDisable(GL_CULL_FACE);
 
 
 typedef void (*helperFunc) (xfieldP xf, int posPerConn, 
@@ -114,6 +131,19 @@ static Error
 #define OPAQUE_PRIMS      1
 #define TRANSLUCENT_PRIMS 2
 
+/*  We presume OpenGL >= 1.2. */
+/*  If < OpenGL 1.3...        */
+#ifndef GL_CLAMP_TO_BORDER
+#  ifdef sgi
+#    define GL_CLAMP_TO_BORDER GL_CLAMP_TO_BORDER_SGIS
+#  else
+#    define GL_CLAMP_TO_BORDER 0x812D
+#  endif
+#endif
+#ifndef GL_CLAMP_TO_EDGE
+#  define GL_CLAMP_TO_EDGE 0x812F
+#endif
+
 
 /*-------- These happen once per field -- outside glBegin/glEnd -------*/
 
@@ -268,9 +298,7 @@ static int depthMaskState;
   int _lit = lit && xf->normalsDep != dep_none;				\
  									\
   if (xf->attributes.front.ambient == xf->attributes.front.diffuse) 	\
-  {									\
-    separateAmbientAndDiffuse = 0;					\
-  }									\
+      separateAmbientAndDiffuse = 0;					\
   else									\
       separateAmbientAndDiffuse = 1;					\
 									\
@@ -312,14 +340,14 @@ static int depthMaskState;
 									\
   if(doesTrans)								\
   {									\
-    if (xf->colorsDep == dep_field) {					\
+    if (xf->colorsDep == dep_field) {                                   \
       if (xf->opacitiesDep == dep_none) SENDCOLOR			\
       else if (xf->opacitiesDep == dep_field) SENDCOLOROPACITY;		\
     }									\
   }									\
   else									\
      OPACITY_STIPPLE;							\
-}	
+}
 
 #define ENDPERFIELD()							\
 {									\
@@ -407,7 +435,7 @@ static Error translucentPoints (xfieldP xf, helperFunc helper,
 				 enum approxE approx, int skip)
 {
   static float	fscratch[3];
-  static int	iscratch;
+  static long	iscratch;
   int		i = 0, c, c1;
 
   glBegin(GL_POINTS);
@@ -443,7 +471,7 @@ static Error points (xfieldP xf, helperFunc helper,
 {
   static int	translation[8];
   static float	fscratch[3];
-  static int	iscratch;
+  static long	iscratch;
   int		i = 0, c;
   dependencyT   odep;
   int 		translu;
@@ -714,8 +742,7 @@ static Error polygons (xfieldP xf, helperFunc helper,
    static int	iscratch;
    register int	c;
    register int	c1, translu = 0;
-   dependencyT   odep;
-
+   dependencyT  odep;
 
    ENTRY(("polygons(0x%x, 0x%x, %d, %d, %d, %d, %d)",
 	  xf, helper, firstConnection, lastConnection, face, approx, skip));
@@ -878,6 +905,11 @@ static int _drawTranslucentPrimitives(tdmPortHandleP portHandle, xfieldP xf,
          translucentPolygons(xf,helper,list,n,9,approx,density) ;
          TIMER("< cubes") ;
          break;
+      case ct_tmesh:
+      case ct_qmesh:
+         /*  Note: we don't mesh translucent prims, so we'll never get here  */
+         goto error;
+         break;
       default:
          goto error;
          break;
@@ -1364,73 +1396,6 @@ static Error bbox (xfieldP xf)
 }
 
 
-/*
- * texture-mapping helpers
- */
-
-static void
-TNnone (xfieldP xf, int posPerConn, int ctIndex, int *translation)
-{
-  static  float	fscratch[3];
-  static  float	uvscratch[2];
-  static  int	p;
-
-  ENTRY(("TNnone(0x%x, %d, %d, 0x%x)",
-	 xf, posPerConn, ctIndex, translation));
-
-  for(p=0;p<posPerConn;p++)  {
-    int q = translation[p];
-    SENDUV(q);
-    SENDPOSITION(q);
-  }
-
-  EXIT((""));
-}
-
-static void
-TNconnections (xfieldP xf, int posPerConn, int ctIndex, int *translation)
-{
-  static float	fscratch[3];
-  static float	uvscratch[2];
-  static int	p;
-  GLubyte c = 0xff;
-
-
-  ENTRY(("TNconnections(0x%x, %d, %d, 0x%x)",
-	 xf, posPerConn, ctIndex, translation));
-
-  SENDNORMAL(ctIndex);
-  glColor3ub(c,c,c);
-  for(p=0;p<posPerConn;p++)  {
-    SENDUV(translation[p]);
-    SENDPOSITION(translation[p]);
-  }
-
-  EXIT((""));
-}
-
-static void
-TNpositions (xfieldP xf, int posPerConn, int ctIndex, int *translation)
-{
-  static float	fscratch[3];
-  static float	uvscratch[2];
-  static int	p;
-  GLubyte c = 0xff;
-
-  ENTRY(("TNpositions(0x%x, %d, %d, 0x%x)",
-	 xf, posPerConn, ctIndex, translation));
-
-  glColor3ub(c,c,c);
-  for(p=0;p<posPerConn;p++)  {
-    int q = translation[p];
-    SENDUV(q);
-    SENDNORMAL(q);
-    SENDPOSITION(q);
-  }
-
-  EXIT((""));
-}
-
 #include "hwPortUtilOGL.help"
 
 static helperFunc
@@ -1444,31 +1409,10 @@ getHelper(dependencyT colorsDep,
 
   ENTRY(("getHelper(%d, %d, %d)",colorsDep,normalsDep,opacitiesDep));
 
-  if (texture)
-  {
-      if (normalsDep == dep_connections) return TNconnections;
-      else if (normalsDep == dep_positions) return TNpositions;
-      else return TNnone;
-  }
-
-#if 0
-  if(colorsDep == dep_none) colorsDep = dep_field;
-  if(opacitiesDep == dep_none) opacitiesDep = dep_field;
-  opacitiesDep = dep_field;
-
-  index = (( (int)opacitiesDep-1) * 3 + ((int)normalsDep)) * 3 + 
-    ((int)colorsDep-1);
-  ret = helperTable[index];
-
-  EXIT(("ret = 0x%x",ret));
-#endif
-
-  index = getIndex(colorsDep, normalsDep, opacitiesDep);
+  index = getIndex(colorsDep, normalsDep, opacitiesDep,texture);
   ret = helperTable[index];
 
   return ret;
-
-
 }
 
 static Error
@@ -1655,6 +1599,7 @@ Error _dxf_DrawTranslucentOGL(void *globals,
   Light		newLight;
   float 	fscratch[3];
   int   	iscratch;
+  dxObject      dlist = NULL;
 
   ENTRY(("_dxf_DrawTranslucentOGL(0x%x, 0x%x, 0x%x, 0x%x)",
          PORT_HANDLE, xf, ambientColor, buttonUp));
@@ -1663,11 +1608,16 @@ Error _dxf_DrawTranslucentOGL(void *globals,
   OGL_FAIL_ON_ERROR(glEnableBlend);
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   OGL_FAIL_ON_ERROR(glBlendFunc);
+  glAlphaFunc(GL_GREATER, 0.0);
+  OGL_FAIL_ON_ERROR(glAlphaFunc);
 
   for (i = 0; i < nSorted; i = j)
   {
     xf = (xfieldP)sorted[i].xfp;
 
+    Cull(xf);
+    LightModel(xf);
+
     if(xf->normalsDep != dep_none &&
         xf->attributes.buttonUp.approx == approx_none)
     {
@@ -1707,11 +1657,35 @@ Error _dxf_DrawTranslucentOGL(void *globals,
 				   (float)xf->attributes.front.shininess);
     } /* end normals & no approximation */
 
-    if(xf->texture)
+    if (xf->texture)
     {
-       loadTexture(xf);
-       startTexture();
+	if (DXGetObjectTag((dxObject)xf->texture_field) != CURTEX)
+	{
+	    CURTEX = DXGetObjectTag((dxObject)xf->texture_field);
+
+	    if (DO_DISPLAY_LISTS)
+	    {
+		dlist = _dxf_QueryObject(TEXTURE_HASH, (dxObject)xf->texture_field);
+		if (dlist)
+		    _dxf_callDisplayListOGL(dlist);
+		else
+		{
+		    dlist = _dxf_openDisplayListOGL();
+		    loadTexture(xf);
+		    _dxf_endDisplayListOGL();
+		    _dxf_InsertObject(TEXTURE_HASH, (dxObject)xf->texture_field, dlist);
+		    dlist = NULL;
+		}
+	    }
+	    else
+		loadTexture(xf);
+	}
+
+	startTexture(xf);
     }
+    else
+	endTexture();
+
 
     if (xf->nClips)
       if (! _dxf_ADD_CLIP_PLANES(LWIN, xf->clipPts, xf->clipVecs, xf->nClips))
@@ -1791,13 +1765,24 @@ Error _dxf_DrawOpaqueOGL(tdmPortHandleP portHandle, xfieldP xf,
   Light		newLight;
   dxObject      dlist = NULL;
   DEFPORT(portHandle) ;
+  hwFlags attFlags = _dxf_attributeFlags(_dxf_xfieldAttributes(xf));
+  int alphaTexture = (int) _dxf_isFlagsSet(attFlags,
+					   CONTAINS_TRANSPARENT_TEXTURE);
 
   ENTRY(("_dxf_DrawOpaqueOGL(0x%x, 0x%x, 0x%x, 0x%x)",
 	 portHandle, xf, ambientColor, buttonUp));
 
+  /*  Alpha texture translucency is trapped out here.  Opacities            */
+  /*     translucency caught in the primitive rendering funcs per element.  */
+  if (alphaTexture) {
+    EXIT(("OK"));
+    return OK;
+  }
+
   doesTrans = _dxf_isFlagsSet(_dxf_SERVICES_FLAGS(), SF_DOES_TRANS);
 
   Cull(xf);
+  LightModel(xf);
 
   if(xf->normalsDep != dep_none &&
      xf->attributes.buttonUp.approx == approx_none)
@@ -1830,7 +1815,7 @@ Error _dxf_DrawOpaqueOGL(tdmPortHandleP portHandle, xfieldP xf,
     ambient = ambient/diffuse;
     /*
      * DEFINE_LIGHT takes the sqrt() of the input, so we need to square 
-     * the coeficient here
+     * the coefficient here
      */
     ambient = ambient * ambient;
     ambientColor.r *= ambient;
@@ -1904,7 +1889,7 @@ Error _dxf_DrawOpaqueOGL(tdmPortHandleP portHandle, xfieldP xf,
 	      loadTexture(xf);
       }
 
-      startTexture();
+      startTexture(xf);
   }
   else
       endTexture();
@@ -1952,6 +1937,7 @@ Error _dxf_DrawOpaqueOGL(tdmPortHandleP portHandle, xfieldP xf,
   _dxf_POP_MATRIX(PORT_CTX) ;
 
   OGL_FAIL_ON_ERROR(_dxf_DrawOpaqueOGL);
+
   EXIT(("OK"));
   return OK;
 
@@ -2162,17 +2148,62 @@ WriteToFile(char *s, xfieldP xf, int type, float mat[4][4])
 }
 #endif
 
+static int isGLExtensionSupported( const char *extension )
+  /* Blatent copy from: 
+   *    http://www.opengl.org/developers/code/features/OGLextensions/\
+   *    OGLextensions.html
+   */
+{
+  const GLubyte *extensions = NULL;
+  const GLubyte *start;
+  GLubyte *where, *terminator;
+
+  /* Extension names should not have spaces. */
+  where = (GLubyte *) strchr(extension, ' ');
+  if (where || *extension == '\0')
+    return 0;
+  extensions = glGetString(GL_EXTENSIONS);
+  /* It takes a bit of care to be fool-proof about parsing the
+     OpenGL extensions string. Don't be fooled by sub-strings,
+     etc. */
+  start = extensions;
+  for (;;) {
+      where = (GLubyte *) strstr((const char *) start, extension);
+      if (!where)
+          break;
+      terminator = where + strlen(extension);
+      if (where == start || *(where - 1) == ' ')
+          if (*terminator == ' ' || *terminator == '\0')
+              return 1;
+      start = terminator;
+  }
+  return 0;
+}
+
+static int glSupports_CLAMP_TO_BORDER( void )
+{
+#ifdef GL_VERSION_1_3
+  return 1;
+#else
+  static int Texture_border_supported = -1;
+  if ( Texture_border_supported < 0 ) 
+    Texture_border_supported = 
+      ( !isGLExtensionSupported("SGIS_texture_border_clamp") &&
+        !isGLExtensionSupported("GL_ARB_texture_border_clamp") );
+  return Texture_border_supported;
+#endif
+}
+
+
 static void
 loadTexture(xfieldP xf)
 {
-    glTexImage2D(GL_TEXTURE_2D, 0, 3, xf->textureWidth,
-		xf->textureHeight, 0, GL_RGB, GL_UNSIGNED_BYTE,
-		(GLubyte *)xf->texture);
-    glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
-    glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
-    glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-    glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-    glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+    /*  Set texture  */
+    GLenum type    = xf->textureIsRGBA ? GL_RGBA : GL_RGB;
+    GLint  int_fmt = xf->textureIsRGBA ? 4 : 3;
+    gluBuild2DMipmaps(GL_TEXTURE_2D, int_fmt, xf->textureWidth,
+                 xf->textureHeight, type, GL_UNSIGNED_BYTE,
+                 (GLubyte *)xf->texture);
 
     glMatrixMode(GL_TEXTURE);
     glLoadIdentity();
@@ -2180,8 +2211,68 @@ loadTexture(xfieldP xf)
 }
 
 static void
-startTexture()
+startTexture(xfieldP xf)
 {
+    static struct 
+      { textureFilterE dx; GLint gl; }
+    filter_to_gl[] = { 
+      { tf_nearest               , GL_NEAREST },
+      { tf_linear                , GL_LINEAR  },
+      { tf_nearest_mipmap_nearest, GL_NEAREST_MIPMAP_NEAREST },
+      { tf_nearest_mipmap_linear , GL_NEAREST_MIPMAP_LINEAR  },
+      { tf_linear_mipmap_nearest , GL_LINEAR_MIPMAP_NEAREST  },
+      { tf_linear_mipmap_linear  , GL_LINEAR_MIPMAP_LINEAR   }
+    };
+    static struct 
+      { textureFunctionE dx; GLint gl; }
+    function_to_gl[] = { 
+      { tfn_decal   , GL_DECAL    }, { tfn_replace , GL_REPLACE  },
+      { tfn_modulate, GL_MODULATE }, { tfn_blend   , GL_BLEND    }
+    };
+    static struct 
+      { textureWrapE dx; GLint gl; }
+    wrap_to_gl[] = { 
+      { tw_clamp , GL_CLAMP   }, { tw_clamp_to_edge  , GL_CLAMP_TO_EDGE   },
+      { tw_repeat, GL_REPEAT  }, { tw_clamp_to_border, GL_CLAMP_TO_BORDER }
+    };
+
+    attributeP attr = &xf->attributes;
+    int i, len;
+    GLint wrap_s, wrap_t, min_filter, mag_filter, function;
+
+    /*  Set texture wrap modes  */
+    wrap_s = wrap_t = GL_CLAMP;
+    len = sizeof(wrap_to_gl)/sizeof(*wrap_to_gl);
+    if ( !glSupports_CLAMP_TO_BORDER() )
+        len--;
+    for ( i = 0; i < len; i++ ) {
+      if ( attr->texture_wrap_s == wrap_to_gl[i].dx )
+        wrap_s = wrap_to_gl[i].gl;
+      if ( attr->texture_wrap_t == wrap_to_gl[i].dx )
+        wrap_t = wrap_to_gl[i].gl;
+    }
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, wrap_s);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, wrap_t);
+
+    /*  Set texture filters  */
+    min_filter = GL_NEAREST, mag_filter = GL_NEAREST;
+    for ( i = 0; i < sizeof(filter_to_gl)/sizeof(*filter_to_gl); i++ ) {
+      if ( attr->texture_min_filter == filter_to_gl[i].dx )
+        min_filter = filter_to_gl[i].gl;
+      if ( attr->texture_mag_filter == filter_to_gl[i].dx )
+        mag_filter = filter_to_gl[i].gl;
+    }
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, min_filter);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, mag_filter);
+
+    /*  Set texture function  */
+    function = GL_MODULATE;
+    for ( i = 0; i < sizeof(function_to_gl)/sizeof(*function_to_gl); i++ )
+      if ( attr->texture_function == function_to_gl[i].dx )
+        function = function_to_gl[i].gl;
+    glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, function);
+
+    /*  And activate texuring  */
     glEnable(GL_TEXTURE_2D);
 }
 
@@ -2346,4 +2437,3 @@ main()
 		
 		
 #endif
-
