@@ -109,7 +109,7 @@ Error _dxfreadarray_binary(struct finfo *f, Array a, int format)
     Type type;
     int items, actual;
 
-#if WORDS_BIGENDIAN==1
+#if defined(WORDS_BIGENDIAN)
     int nonnative = D_LSB;
 #else
     int nonnative = D_MSB;
@@ -793,10 +793,9 @@ swap_64(void *src, void *dest, int n, int swaps)
     unsigned int *d = (unsigned int*)dest;
     unsigned int x,y,i;
     
-    if (((int)s & 3) || ((int)d & 3)) 
+    if (((long)s & 3) || ((long)d & 3)) 
 	DXErrorGoto(ERROR_INTERNAL,"Tried to swap non-word aligned data");
     
-    
     switch (swaps) {
       case (WORD_SWAP|HWORD_SWAP|BYTE_SWAP):
 	  for (i=0 ; i<n ; i++) {
