@@ -33,7 +33,7 @@
  * complication here is due to System V shared memory segments, which
  * are rather difficult to use for this purpose.  This file provides:
  *
- * Error _dxfsetmem(int limit)
+ * Error _dxfsetmem(ulong limit)
  *     Called before getmem or getbrk with the total of the small/large 
  *     arena sizes in bytes.
  *
@@ -41,13 +41,13 @@
  *     Called after the first getmem/getbrk but before any forks;
  *     can be used to initialize lock tables.
  *
- * Pointer _dxfgetmem(Pointer base, int size)
+ * Pointer _dxfgetmem(Pointer base, ulong size)
  *     Request for a shared memory segment starting at base of the given
  *     size.  Guaranteed to be initialized to zeroes. Calls signal_allprocs
  *     so each process can attach to the new memory segment. Returns 
  *     actual address of the segment, or NULL for error
  *
- * Pointer _dxfgetbrk(Pointer base, int size)
+ * Pointer _dxfgetbrk(Pointer base, ulong size)
  *     Alternative to _dxfgetmem.  Calls the brk() system call to expand
  *     the existing data segment.  Defined at the end of the file instead
  *     of in the system-dependent sections because it's the same for all.
@@ -64,10 +64,18 @@
  *     the shared memory pool.
  */
 
+#if defined(HAVE_WINDOWS_H)
+#include <windows.h>
+#endif
+
 #if defined(HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 
+#if defined(HAVE_ERRNO_H)
+#include <errno.h>
+#endif
+
 #include <string.h>
 #include <dx/dx.h>
 #include "../dpexec/dxmain.h"
@@ -77,15 +85,14 @@
  *  exec, and they are basically private routines which shouldn't
  *  be exposed.
  */
-Error _dxfsetmem(int limit);
+Error _dxfsetmem(ulong limit);
 Error _dxfinitmem();
-Pointer _dxfgetmem(Pointer base, int size);
-Pointer _dxfgetbrk(Pointer base, int size);
+Pointer _dxfgetmem(Pointer base, ulong size);
+Pointer _dxfgetbrk(Pointer base, ulong size);
 int   _dxfinmem(Pointer x);
 Error DXsyncmem();
 Error DXmemfork(int);
 
-
 /* moved out of memstats conditional section.  i'm going to use this to tell
  * what kind of memory we are using - shared or dataseg - so when we are
  * called to extend the segment we can do the right thing.  it's getting 
@@ -128,11 +135,11 @@ void _dxfcleanup_mem() { }
 
 
 
-
 #if ibm6000 || sgi || solaris || alphax || hp700 || linux
 
 #define memroutines
 
+#include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ipc.h>
@@ -142,7 +149,6 @@ void _dxfcleanup_mem() { }
 #include <stdlib.h>
 #include <fcntl.h>
 
-
 /* no resizing; allocate enough space initially. 
  *
  * the address space needs to be contiguous, so allow system to pick
@@ -154,20 +160,53 @@ void _dxfcleanup_mem() { }
  *
  */
 
-#ifndef SHMMAX
-#define SHMMAX (1<<28)      /* 256 Mb */
-#endif
-
 #if ibm6000
 #define DATASEG_LIMIT (255 * 1024L * 1024L)
 #endif
 
+ulong
+getSHMMAX()
+{
+    ulong shmmax = 0;
+
+#if linux
+    FILE *fd = fopen("/proc/sys/kernel/shmmax", "r");
+    if (fd)
+    {
+        fscanf(fd, "%lu", &shmmax);
+	fclose(fd);
+    }
+    else
+    {
+        /*
+	 * A problem here ... SHMMAX is defined in linux/shm.h,
+	 * but if we include that, all hell breaks loose with 
+	 * redefined structures.
+	 */
+        shmmax = 0x2000000;
+    }
+#endif
+
+    if (shmmax == 0)
+    {
+#if defined(SHMMAX)
+	shmmax = SHMMAX;
+#else
+	/* wishful thinking... 256 Meg */
+	shmmax = (1 << 28); 
+#endif
+    }
+
+    return shmmax;
+}
+
+
 extern int _dxd_exRunningSingleProcess;   /* boolean supplied by the exec */
 
 /* move this logic out of dxfsetmem() into its own routine.  it's
  * gotten too complicated.
  */
-static Error whatkindofmem(int limit)
+static Error whatkindofmem(ulong limit)
 {
     int force = 0;    /* set if the user requested a particular choice */
     char *cp = NULL;
@@ -189,6 +228,13 @@ static Error whatkindofmem(int limit)
      * (see man ld, look for -bmaxdata) which cause problems with other
      * runtime-loaded code like the opengl libs.
      *
+     * (sgi note) the following description of DX behavior is still the
+     * case but the allegations about IRIX vfork aren't quite accurate.  On
+     * IRIX, fork()/vfork() are like BSD vfork() but the pages are marked
+     * MAP_PRIVATE rather than MAP_SHARED, so they don't get copied unless
+     * modified.  However, the page table does get duplicated.
+     * Performance-wise this is similar to the BSD vfork().
+     *
      * on the sgi only, always use shared memory.  all other platforms
      * have vfork(), which does NOT copy the current process on a fork.
      * this is good because you are turning around and execing a second
@@ -198,8 +244,7 @@ static Error whatkindofmem(int limit)
      * neither fork() nor vfork() copy shared memory, so by using that
      * instead of expanding the data segment, ! filters and system() and
      * other things which require a fork/exec have a chance of working.
-     *
-     */
+     * */
 
     /* user override - force using shared memory or the data segment.  
      * set the value, but go ahead and check to see if we'd have to set it
@@ -274,15 +319,16 @@ static Error whatkindofmem(int limit)
  * buy us a factor of e6 in size in an int.
  */
 Error
-_dxfsetmem(int limit)
+_dxfsetmem(ulong limit)
 {
-    int size, maxsegsize = SHMMAX;
+    ulong size, maxsegsize = getSHMMAX();
     int id, nchunk, nextseg;
     int i, j;
     int first = 1;
     Pointer sh_base[MAX_CHUNKS]; 
-    int gotten[MAX_CHUNKS], nsegs[MAX_CHUNKS];
-    uint totalsize = 0;
+    ulong gotten[MAX_CHUNKS];
+    int    nsegs [MAX_CHUNKS];
+    ulong totalsize = 0;
     Pointer tbase, tend;
     int tcount;
     extern int errno;
@@ -305,7 +351,12 @@ _dxfsetmem(int limit)
      */
     if ((cp = getenv("DXSHMEMSEGMAX")) != NULL) {
 	maxsegsize = atoi(cp);
-	if (maxsegsize <= 0 || maxsegsize > 2048) {
+#ifdef ENABLE_LARGE_ARENAS
+	if (maxsegsize <= 0)
+#else
+	if (maxsegsize <= 0 || maxsegsize > 2048)
+#endif
+	{
 	    DXSetError(ERROR_BAD_PARAMETER, 
       "bad shared memory segment size limit, DXSHMEMSEGMAX = %d Megabytes",
 			  maxsegsize);
@@ -441,7 +492,7 @@ _dxfsetmem(int limit)
 
 
 Pointer
-_dxfgetmem(Pointer base, int size)
+_dxfgetmem(Pointer base, ulong size)
 {
     int i;
 
@@ -504,12 +555,13 @@ _dxfinmem(Pointer x)
 
 #endif   /* ibm6000, solaris, sgi, alpha, hp700 */
 
-#if defined(intelnt)
-
-#ifndef DXD_WIN_SHARE_MEMORY
+#if defined(macos)
 #define memroutines
-void *sh_base;   /* starting virtual address */
-Error _dxfsetmem(int limit)
+
+/* Still need to write shared memory routines */
+
+void *sh_base = NULL;   /* starting virtual address */
+Error _dxfsetmem(ulong limit)
 {
     sh_base = malloc(limit);
     if (sh_base == NULL) {
@@ -521,7 +573,195 @@ Error _dxfsetmem(int limit)
     }
 }
 
-Pointer _dxfgetmem(Pointer base, int size)
+Pointer _dxfgetmem(Pointer base, ulong size)
+{
+    if (!base)	
+	base = (Pointer) sh_base;
+
+    return base;
+}
+#endif /* defined(macos) */
+
+
+#if defined(intelnt) || defined(WIN32)
+
+#if defined(USE_AWE)
+
+/*****************************************************************
+   LoggedSetLockPagesPrivilege: a function to obtain, if possible, or
+   release the privilege of locking physical pages.
+
+   Inputs:
+
+       HANDLE hProcess: Handle for the process for which the
+       privilege is needed
+
+       BOOL bEnable: Enable (TRUE) or disable?
+
+   Return value: TRUE indicates success, FALSE failure.
+
+*****************************************************************/
+BOOL
+LoggedSetLockPagesPrivilege ( HANDLE hProcess,
+							 BOOL bEnable)
+{
+	struct {
+		DWORD Count;
+		LUID_AND_ATTRIBUTES Privilege [1];
+	} Info;
+	
+	HANDLE Token;
+	BOOL Result;
+	
+	Result = OpenProcessToken ( hProcess,
+		TOKEN_ADJUST_PRIVILEGES,
+		& Token);
+	
+	if( Result != TRUE ) {
+		DXSetError(ERROR_NO_MEMORY, "Cannot open process token.\n" );
+		return FALSE;
+	}
+	
+	Info.Count = 1;
+	if( bEnable ) 
+	{
+		Info.Privilege[0].Attributes = SE_PRIVILEGE_ENABLED;
+	} 
+	else 
+	{
+		Info.Privilege[0].Attributes = 0;
+	}
+	
+	Result = LookupPrivilegeValue ( NULL,
+		SE_LOCK_MEMORY_NAME,
+		&(Info.Privilege[0].Luid));
+	
+	if( Result != TRUE ) 
+	{
+		DXSetError(ERROR_NO_MEMORY, "Cannot get privilege value for %s.\n", SE_LOCK_MEMORY_NAME );
+		return FALSE;
+	}
+	
+	Result = AdjustTokenPrivileges ( Token, FALSE,
+		(PTOKEN_PRIVILEGES) &Info,
+		0, NULL, NULL);
+	
+	if( Result != TRUE ) 
+	{
+		DXSetError(ERROR_NO_MEMORY, "Cannot adjust token privileges, error %u.\n", GetLastError() );
+		return FALSE;
+	} 
+	else 
+	{
+		if( GetLastError() != ERROR_SUCCESS ) 
+		{
+			DXSetError(ERROR_NO_MEMORY, "Cannot enable SE_LOCK_MEMORY privilege, please check the local policy.\n");
+			return FALSE;
+		}
+	}
+	
+	CloseHandle( Token );
+	
+	return TRUE;
+}
+
+#endif
+
+#ifndef DXD_WIN_SHARE_MEMORY
+#define memroutines
+void *sh_base;   /* starting virtual address */
+
+
+DWORD GetPageSize(void) {
+	SYSTEM_INFO SystemInfo;
+	GetSystemInfo(&SystemInfo);
+	return SystemInfo.dwPageSize;
+}
+
+Error _dxfsetmem(ulong limit)
+{
+	/* Determine if we should use the AWE extensions and lock physical
+	   memory. Can give us significant speed up. Only available with
+	   Win2K or better and user must have special priveledges. See AWE
+	   extensions in MSDN. 
+	*/
+#if defined(USE_AWE)
+	HANDLE hProcess = GetCurrentProcess();
+	ULONG_PTR pnPages;
+	PULONG_PTR ppPFN;
+	int PFNArraySize;
+
+	pnPages = limit / GetPageSize();
+	if (limit % GetPageSize() ) { pnPages += 1; }
+	
+	PFNArraySize = sizeof(ULONG_PTR) * pnPages;
+
+	ppPFN = (PULONG_PTR) HeapAlloc (GetProcessHeap(), 0, PFNArraySize); /* Allocate PFN array */
+	
+	if( ! LoggedSetLockPagesPrivilege( GetCurrentProcess(), TRUE ) ) {
+		DXErrorReturn(ERROR_NO_MEMORY, "Cannot get priveledges to lock physical memory.");
+	}
+
+	if(AllocateUserPhysicalPages(hProcess, &pnPages, ppPFN) ) {
+		limit = pnPages * GetPageSize(); /* May return fewer pages than asked for */
+		sh_base = VirtualAlloc(NULL, limit, MEM_RESERVE | MEM_PHYSICAL, PAGE_READWRITE);
+		if(sh_base == 0) {
+			LPVOID lpMsgBuf;
+			FormatMessage( 
+				FORMAT_MESSAGE_ALLOCATE_BUFFER | 
+				FORMAT_MESSAGE_FROM_SYSTEM | 
+				FORMAT_MESSAGE_IGNORE_INSERTS,
+				NULL,
+				GetLastError(),
+				MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), /* Default language */
+				(LPTSTR) &lpMsgBuf,
+				0,
+				NULL 
+				);
+			DXErrorReturn(ERROR_NO_MEMORY, (char *) lpMsgBuf);
+			LocalFree( lpMsgBuf );
+		}
+		MapUserPhysicalPages(sh_base, pnPages, ppPFN);
+	} else {
+		LPVOID lpMsgBuf;
+		FormatMessage( 
+			FORMAT_MESSAGE_ALLOCATE_BUFFER | 
+			FORMAT_MESSAGE_FROM_SYSTEM | 
+			FORMAT_MESSAGE_IGNORE_INSERTS,
+			NULL,
+			GetLastError(),
+			MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), /* Default language */
+			(LPTSTR) &lpMsgBuf,
+			0,
+			NULL 
+			);
+		DXErrorReturn(ERROR_NO_MEMORY, (char *) lpMsgBuf);
+		LocalFree( lpMsgBuf );
+	}
+
+#else
+	sh_base = VirtualAlloc(NULL, limit, MEM_COMMIT, PAGE_READWRITE);
+	if(sh_base == 0) {
+		LPVOID lpMsgBuf;
+		FormatMessage( 
+			FORMAT_MESSAGE_ALLOCATE_BUFFER | 
+			FORMAT_MESSAGE_FROM_SYSTEM | 
+			FORMAT_MESSAGE_IGNORE_INSERTS,
+			NULL,
+			GetLastError(),
+			MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), /* Default language */
+			(LPTSTR) &lpMsgBuf,
+			0,
+			NULL 
+			);
+		DXErrorReturn(ERROR_NO_MEMORY, (char *) lpMsgBuf);
+		LocalFree( lpMsgBuf );
+	}
+#endif
+	return OK;
+}
+
+Pointer _dxfgetmem(Pointer base, ulong size)
 {
     if (!base)	
 	base = (Pointer) sh_base;
@@ -534,6 +774,7 @@ Error DXmemfork(int i)
 #if 0
     return fork(); I hope this is not needed -- GDA
 #endif
+		return 0;
 }
 
 
@@ -557,10 +798,10 @@ void *sh_base;   /* starting virtual address */
 
 HANDLE MapFileHandle, MapHandle;
 LPVOID MappedPointer;
-static  int DXLimit;
+static  ulong DXLimit;
 
 
-Error _dxfsetmem(int limit)
+Error _dxfsetmem(ulong limit)
 {
     /*  Create Map file   */
     char DX_MAP_FILE[32];
@@ -608,7 +849,7 @@ Error _dxfsetmem(int limit)
 }
 
 
-Pointer _dxfgetmem(Pointer base, int size)
+Pointer _dxfgetmem(Pointer base, ulong size)
 {
     /*  static HANDLE MapFileHandle, MapHandle;   */
     char DX_MAP_FILE[32];
@@ -643,24 +884,23 @@ Error DXmemfork(int i)
 #endif   
 
 #if os2
-
 #define memroutines
 
 static PVOID sh_base;   /* starting virtual address */
 
 Error
-_dxfsetmem(int limit)
+_dxfsetmem(ulong limit)
 {
 
     if (DosAllocSharedMem(&sh_base, "\\sharemem\\dx.dat",
-	limit, PAG_READ | PAG_WRITE)) {
+	(int)limit, PAG_READ | PAG_WRITE)) {
 	DXErrorReturn(ERROR_NO_MEMORY, "setmem can't allocate memory");
     } else
         return OK ;
 }
 
 Pointer
-_dxfgetmem(Pointer base, int size)
+_dxfgetmem(Pointer base, ulong size)
 {
     if (!base) 
 	base = (Pointer)sh_base;
@@ -685,14 +925,14 @@ DXmemfork(int i)
 #define memroutines
 #include <sys/svs.h>
 
-Error _dxfsetmem(int limit) { return OK; }
+Error _dxfsetmem(ulong limit) { return OK; }
 Error DXmemfork(int i) { return fork(); }
-Pointer _dxfgetmem(Pointer base, int size) { return base; }
+Pointer _dxfgetmem(Pointer base, ulong size) { return base; }
 
 #endif /* ibmpvs */
 
 
-#if !defined(os2) && !defined(intelnt)
+#if !defined(os2) && !defined(intelnt) && !defined(WIN32)
 
 #if !defined(cygwin) && !defined(macos)
 extern int end;   /* filled in by linker */
@@ -700,7 +940,7 @@ extern int end;   /* filled in by linker */
 
 /* extend the existing data segment
  */
-Pointer _dxfgetbrk(Pointer base, int n)
+Pointer _dxfgetbrk(Pointer base, ulong n)
 {
     Pointer x = (Pointer)sbrk(n);
 
@@ -751,23 +991,23 @@ Pointer _dxfgetbrk(Pointer base, int n)
 extern int end;  /* filled in by linker */
 static Pointer after_end = NULL;
 
-Error _dxfsetmem(int limit)
+Error _dxfsetmem(ulong limit)
 {
     after_end = _dxfgetbrk(limit);
 }
 
-Pointer _dxfgetmem(Pointer base, int size)
+Pointer _dxfgetmem(Pointer base, ulong size)
 {
     return ((base == NULL) ? after_end : base);
 }
 
 #else
-Error _dxfsetmem(int limit)
+Error _dxfsetmem(ulong limit)
 {
     return OK;
 }
 
-Pointer _dxfgetmem(Pointer base, int size)
+Pointer _dxfgetmem(Pointer base, ulong size)
 {
     return _dxfgetbrk(base, size);
 }
@@ -792,7 +1032,10 @@ Error DXmemfork(int i)
  * so the calculations about the size of the data segment can't be done 
  * on the NT.  thus this section is disabled on that platform.
  */
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
+#if defined(MEMSTATS)
+#undef MEMSTATS
+#endif
 #define MEMSTATS 0
 #endif
 
@@ -816,7 +1059,8 @@ extern int end;   /* filled in by linker */
 /* public */
 void DXPrintMemoryInfo()
 {
-    uint i, total;
+    uint i;
+    ulong total;
 
     switch (m) {
       case MEM_NOTINIT:
@@ -831,14 +1075,14 @@ void DXPrintMemoryInfo()
 	    num_sbrk_calls -= num_failed_calls;
 	}
 	for (i=0; i<min(num_sbrk_calls, MAX_CHUNKS); i++)
-	    DXMessage("sbrk %d returned 0x%08x, %u bytes allocated", 
+	    DXMessage("sbrk %d returned 0x%08x, %lu bytes allocated", 
 		      i+1, alloc_addr_start[i], 
-		      (uint)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]));
+		      (ulong)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]));
 	
 #if !defined(cygwin) && !defined(macos)
-	DXMessage("end address = 0x%08x, data segment extended by %u bytes", 
+	DXMessage("end address = 0x%08x, data segment extended by %lu bytes", 
 		  alloc_addr_end[i-1],
-		  (uint)SUB_PTR(alloc_addr_end[i-1], &end));
+		  (ulong)SUB_PTR(alloc_addr_end[i-1], &end));
 #endif
 	return;
 	
@@ -846,14 +1090,14 @@ void DXPrintMemoryInfo()
 	DXMessage("using %d shared memory chunks(s) for arenas", alloc_chunks);
 	total = 0;
 	for (i=0; i<min(alloc_chunks, MAX_CHUNKS); i++) {
-	    DXMessage("chunk %d starts at 0x%08x, %u bytes long (%d segments)", 
+	    DXMessage("chunk %d starts at 0x%08x, %lu bytes long (%d segments)", 
 		      i+1, alloc_addr_start[i], 
-		      (uint)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]), 
+		      (ulong)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]), 
 		      alloc_segments[i]);
-	    total += (uint)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]);
+	    total += (ulong)SUB_PTR(alloc_addr_end[i], alloc_addr_start[i]);
 	}
 	if (i > 1)
-	    DXMessage("end address = 0x%08x, total shared memory = %u bytes", 
+	    DXMessage("end address = 0x%08x, total shared memory = %lu bytes", 
 		      alloc_addr_end[i-1], total);
 	else
 	    DXMessage("end address = 0x%08x", alloc_addr_end[0]);
@@ -863,7 +1107,7 @@ void DXPrintMemoryInfo()
 }
 #endif  /* memory stats */
 
-#if !defined(intelnt)
+#if !defined(intelnt) && !defined(WIN32)
 
 int DXForkChild(int i)
 {
