@@ -656,7 +656,7 @@ int DXCheckRIH (int block)
     EXRIH		r;
     struct timeval	tv;
     int			ret	= FALSE;
-    Error		rval;
+    /*Error		rval;*/
     int			mval;
     int			cfnd;
     int			fd;
@@ -719,7 +719,8 @@ int DXCheckRIH (int block)
 	fd = r->fd;
 	if (r->flag || FD_ISSET(fd, &fdset))
 	{
-	    rval = (* r->proc) (fd, r->arg);
+	    /*rval = (* r->proc) (fd, r->arg);*/
+	    (* r->proc) (fd, r->arg);
 	    ret = TRUE;
 	}
     }
@@ -812,6 +813,12 @@ Pointer DXGetModuleId()
     return id;
 }
 
+Error DXReadyToRunNoExecute(Pointer ida)
+{
+    return OK;
+}
+
+
 Error DXReadyToRun(Pointer id)
 {
     unsigned int signature = 0xEF33AB88;
