@@ -99,6 +99,12 @@ _dxf_VolumeIrregular(struct buffer *b, struct gather *gather, int clip)
 	    z = (((double)p[line.p].z) + ((double)p[line.q].z)) / 2.0;
 	    ADVANCE(1);
 	    break;
+	case SORT_POLYLINE:
+	    line.p = xf->edges[GET(s,1)];
+	    line.q = xf->edges[GET(s,1)+1];
+	    z = (((double)p[line.p].z) + ((double)p[line.q].z)) / 2.0;
+	    ADVANCE(2);
+	    break;
 	case SORT_TRI:
 	    tri = xf->c.triangles[GET(s,0)];
 	    z = (((double)p[tri.p].z) + ((double)p[tri.q].z) + 
@@ -219,7 +225,21 @@ _dxf_VolumeIrregular(struct buffer *b, struct gather *gather, int clip)
 		    goto error;
 	    } else if (xf->colors_dep == dep_connections) {
 		if (!_dxf_LineFlat(b, xf, 1, xf->c.lines, &g,
-			       FCOLORP(g), OPACITYP(g), clip, INV_VALID))
+				xf->fcolors, xf->opacities,
+				clip, INV_VALID))
+		    goto error;
+	    }
+	    break;
+	case SORT_POLYLINE:
+            line.p = xf->edges[GET(s,1)];
+	    line.q = xf->edges[GET(s,1)+1];
+	    if (xf->colors_dep == dep_positions) {
+		if (!_dxf_Line(b, xf, 1, &line, NULL, clip, INV_VALID))
+		    goto error;
+	    } else if (xf->colors_dep == dep_polylines) {
+		if (!_dxf_LineFlat(b, xf, 1, &line, NULL,
+			       xf->fcolors, xf->opacities,
+			       clip, INV_VALID))
 		    goto error;
 	    }
 	    break;
@@ -510,7 +530,7 @@ static Error VolumeRegularPlane(struct buffer *, struct xfield *, int);
 Error
 _dxf_VolumeRegular(struct buffer *b, struct gather *gather, int clip)
 {
-    int i, patch_size = 0;
+    int i /*, patch_size = 0*/;
     struct xfield **xfields, *xf;
     Vector u, v;
     float a, s;
@@ -589,7 +609,7 @@ _dxf_VolumeRegular(struct buffer *b, struct gather *gather, int clip)
 	s = side(u, v);
 	DXDebug("R", "(%.2f,%.2f) x (%.2f,%.2f): area %.2f, side %.2f",
 	      u.x, u.y, v.x, v.y, a, s);
-	patch_size = CEIL(s);
+	/*patch_size = CEIL(s);*/
 	/* XXX - warp doesn't do z yet, or color multipliers */
 	if (s<=1)
 	    b->vol = /*"warp"*/ "plane";
