@@ -51,6 +51,10 @@
 #include <sys/select.h>
 #endif
 
+#if defined(HAVE_UNISTD_H)
+#include <unistd.h>
+#endif
+
 #if   defined(OS2)  || defined(DXD_HAS_WINSOCKETS)
 #if defined(HAVE_IO_H)
 #include <io.h>
@@ -67,7 +71,6 @@ static int _dxl_ReadFromSocket(DXLConnection *conn);
 static int _dxl_WaitForReadable(DXLConnection *conn);
 static int _dxl_IsReadable(DXLConnection *conn);
 static void PrintEvent(DXLEvent *e);
-static void PrintEventList(DXLEvent *e);
 
 static DXLError DXLGetPacket(DXLConnection *, DXLPacketTypeEnum, int,
                 DXLEvent *, int,
@@ -167,21 +170,25 @@ DXLCopyEvent(DXLEvent *dst, DXLEvent *src)
 DXLError
 DXLSend(DXLConnection *conn, const char *string)
 {
-    DXLPacketTypeEnum ptype;
-    int sts;
+    DXLPacketTypeEnum ptype=PACK_FOREGROUND;
 
     if (conn->dxuiConnected) {
 	if (conn->majorVersion <= 2)
 	    ptype = PACK_FOREGROUND;
 	else
 	    ptype = PACK_LINK;
-    } else if (conn->macroDef) {
+	return DXLSendPacket(conn, ptype, string) >= 0 ? OK : ERROR;
+    }
+    else if (conn->macroDef)
+    {
 	DXLSendUnpacketized(conn, string);
-    } else {
-	/* FIXME: is it sufficient to always send in the foreground */
+	return OK;
+    }
+    else
+    {
 	ptype = PACK_FOREGROUND;
+	return DXLSendPacket(conn, ptype, string) >= 0 ? OK : ERROR;
     }
-    return DXLSendPacket(conn, ptype, string) >= 0 ? OK : ERROR;
 
 }
 
@@ -266,9 +273,8 @@ int
 DXLQuery(DXLConnection *conn, const char *string,
          const int length, char *result)
 {
-    int l = STRLEN(string);
-    int found, sts     = 0;
-    int requestId, written = 0;
+    int found;
+    int requestId;
     DXLEvent    event;
     DXLPacketTypeEnum ptype;
 
@@ -406,6 +412,7 @@ DXLNextPacket(DXLConnection *conn, DXLEvent *event)
     return OK;
 }
 
+int
 DXLWaitForEvent(DXLConnection *conn)
 {
     if(conn->nEvents == 0)
@@ -428,7 +435,6 @@ static void DXLDispatchEvent(DXLConnection *conn, DXLEvent *e)
 DXLError
 DXLProcessEventList(DXLConnection *conn)
 {
-    int i;
     DXLEvent *e;
 
     while (_dxl_IsReadable(conn))
@@ -450,9 +456,6 @@ DXLProcessEventList(DXLConnection *conn)
     _dxf_ClearIdleEventHandler(conn);
 
     return OK;
-
-error:
-    return ERROR;
 }
 
 
@@ -673,7 +676,7 @@ _dxl_IsReadable(DXLConnection *conn)
     to.tv_usec = 0;
 
     /* this will restart select if it has been interrupted by a signal */
-    SELECT_INTR(width, (SELECT_ARG_TYPE *)&fds, NULL, NULL, &to, retval);
+	SELECT_INTR((conn->fd + 1), (SELECT_ARG_TYPE *)&fds, NULL, NULL, &to, retval);
 #endif
 
 #ifdef OS2
@@ -738,7 +741,7 @@ _dxl_WaitForReadable(DXLConnection *conn)
     FD_SET(conn->fd, &fds);
 
     /* this will restart select if it was interrupted by a signal */
-    SELECT_INTR(width, (SELECT_ARG_TYPE *)&fds, NULL, NULL, NULL, retval);
+	SELECT_INTR((conn->fd + 1), (SELECT_ARG_TYPE *)&fds, NULL, NULL, NULL, retval);
     if(retval < 0)
         goto error;
 #endif
@@ -751,7 +754,7 @@ _dxl_WaitForReadable(DXLConnection *conn)
 #ifdef DXD_HAS_WINSOCKETS
     FD_ZERO(&fds);
     FD_SET(conn->fd, &fds);
-    width =  select(width, &fds, NULL, NULL, NULL);
+	width =  select((conn->fd + 1), &fds, NULL, NULL, NULL);
     if (width < 0)
         goto error;
 
@@ -872,7 +875,7 @@ _dxl_ReadFromSocket(DXLConnection *conn)
 
 	    msgbuf[nbytes] = '\0';
 
-	    event = DXLNewEvent(id, typei,msgbuf);
+	    event = DXLNewEvent(id, (DXLPacketTypeEnum) typei,msgbuf);
 	    if (!event)
 		goto error;
 	    if (conn->debugMessaging) {
@@ -974,13 +977,7 @@ static void PrintEvent(DXLEvent *e)
 {
     fprintf(stderr, "id %d type %d %s\n", e->serial, e->type, e->contents);
 }
-static void PrintEventList(DXLEvent *e)
-{
-    DXLEvent *event;
 
-    for (event = e; event ; event = event->next)
-        PrintEvent(event);
-}
 int  DXLSetMessageDebugging(DXLConnection *conn, int on)
 {
     int oldval = conn->debugMessaging;
@@ -993,7 +990,6 @@ int  DXLSetMessageDebugging(DXLConnection *conn, int on)
 DXLError
 exDXLBeginMacroDefinition(DXLConnection *conn, const char *mhdr)
 {
-    int l = STRLEN(mhdr);
     int sts = 0;
     DXLPacketTypeEnum ptype;
 
@@ -1020,7 +1016,6 @@ DXLError
 exDXLEndMacroDefinition(DXLConnection *conn)
 {
     int sts = 0;
-    DXLPacketTypeEnum ptype;
 
     if (conn->dxuiConnected)
     {
