@@ -108,9 +108,6 @@ static struct classes
   }
 
 static void Initialize( XmImageWidget request, XmImageWidget new );
-static Boolean SetValues( XmImageWidget current,
-			  XmImageWidget request,
-			  XmImageWidget new );
 static void Realize( register XmImageWidget w, Mask *p_valueMask,
 		     XSetWindowAttributes *attributes );
 
@@ -285,39 +282,43 @@ WidgetClass xmImageWidgetClass = (WidgetClass) &xmImageClassRec;
  */
 static void Initialize( XmImageWidget request, XmImageWidget new )
 {
-Visual *vis;
 int    depth;
 int    screen = XScreenNumberOfScreen(XtScreen(request));
 
     depth = 8;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 8) new->image.supported8 = True;
 
     depth = 12;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 12) new->image.supported12 = True;
 
     depth = 15;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 15) new->image.supported15 = True;
 
     depth = 16;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 16) new->image.supported16 = True;
 
     depth = 24;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 24) new->image.supported24 = True;
 
     depth = 32;
-    vis = getBestVisual(XtDisplay(new), &depth, screen);
+    /*vis =*/ getBestVisual(XtDisplay(new), &depth, screen);
     if(depth == 32) new->image.supported32 = True;
 }
 
 
+#if 0
 /*  Subroutine:	SetValues
  *  Effect:	Handles requests to change things from the application
  */
+static Boolean SetValues( XmImageWidget current,
+			  XmImageWidget request,
+			  XmImageWidget new );
+
 static Boolean SetValues( XmImageWidget current,
 			  XmImageWidget request,
 			  XmImageWidget new )
@@ -326,6 +327,7 @@ static Boolean SetValues( XmImageWidget current,
 
     return redraw;
 }
+#endif
 
 /*  Subroutine:	Realize
  *  Purpose:	Create the window with PointerMotion events and None gravity
@@ -335,7 +337,6 @@ static void Realize( register XmImageWidget w, Mask *p_valueMask,
 {
 Mask valueMask = 	*p_valueMask;
 Window 			root;
-XSetWindowAttributes 	win_values; /* window attribute values */
 XStandardColormap 	cmap_info;
 XVisualInfo 		visual_info;    /* temp storage for a visual data */
 unsigned int 		black, white;
@@ -449,7 +450,7 @@ XButtonPressedEvent * event;
 {
    XmGadget gadget;
 
-   if ((gadget = _XmInputInGadget((Widget)da, event->x, event->y)) != NULL)
+   if ((gadget = (XmGadget) _XmInputInGadget((Widget)da, event->x, event->y)) != NULL)
    {
       _XmDispatchGadgetInput ((Widget)gadget, (XEvent *)event, XmARM_EVENT);
       da->manager.selected_gadget = gadget;
@@ -512,7 +513,7 @@ getBestVisual (Display *dpy, int *depth, int screen)
 
 #ifdef FORCE_VISUAL
     {
-	char *str, *name;
+	char *str;
 	int  depth;
 
 	str = (char *)getenv("DXVISUAL");
@@ -624,7 +625,7 @@ getBestVisual (Display *dpy, int *depth, int screen)
     if (ret)
 	return ret;
 
-    template.screen - screen;
+    template.screen = screen;
     vismask = VisualScreenMask;
     visualInfo = XGetVisualInfo(dpy,vismask,&template,&count);
     *depth =  visualInfo->depth; 
