@@ -31,6 +31,7 @@
 #include <Xm/XmP.h>
 #include <Xm/ScrolledW.h>
 #include <Xm/ScrolledWP.h>
+#include <Xm/Label.h>
 #include "NumericList.h"
 #include "NumericListP.h"
 
@@ -230,9 +231,6 @@ WidgetClass xmNumericListWidgetClass = (WidgetClass) &xmNumericListClassRec;
 static void Initialize( XmNumericListWidget request, XmNumericListWidget new )
 {
 XmFontList	font_list;
-int		n;
-int		i;
-int		j;
 Widget		label;
 Arg		wargs[100];
 unsigned long	space;
@@ -322,7 +320,6 @@ static Boolean SetValues( XmNumericListWidget current,
 {
 Boolean dolayout = False;
 Boolean redraw = False;
-XSetWindowAttributes attributes;
 
     if (new->numeric_list.decimal_places != 
 	current->numeric_list.decimal_places)
@@ -454,9 +451,7 @@ char			tmp[100];
 GC			gc;
 Dimension		x;
 Dimension		y;
-XCharStruct		overall;
 Dimension		width;
-Boolean			fixed_format;
 int			k;
 
     y = vector_number * nlw->numeric_list.line_height;	
@@ -523,19 +518,19 @@ int			k;
 	{
 	    sprintf(string, e_format[i], 
 		    *(nlw->numeric_list.local_vectors[vector_number] + i));
-	    fixed_format = False;
+	    /*fixed_format = False;*/
 	}
 	else
 	{
 	    sprintf(string, f_format[i], 
 		    *(nlw->numeric_list.local_vectors[vector_number] + i));
-	    fixed_format = True;
+	    /*fixed_format = True;*/
 	}
 	if (STRLEN(string) > nlw->numeric_list.local_decimal_places[i] + 7)
 	{
 	    sprintf(string, e_format[i], 
 		    *(nlw->numeric_list.local_vectors[vector_number] + i));
-	    fixed_format = False;
+	    /*fixed_format = False;*/
 	}
 
 	k = 0;
@@ -881,17 +876,12 @@ char		**e_format;
 char		**f_format;
 char		string[100];
 int		k;
-Dimension	ret_width;
-Dimension	ret_height;
 Dimension	sw_width;
 Arg		wargs[20];
 int		n;
-XtGeometryResult status;
 XtWidgetGeometry request;
 XtWidgetGeometry reply;
 Widget          clip_window;
-Boolean		fixed_format;
-
 
     /*
      * Calculate the height required for each line.
@@ -914,7 +904,7 @@ Boolean		fixed_format;
     if(nlw->numeric_list.vsb) XtUnmanageChild(nlw->numeric_list.vsb);
     request.request_mode = CWHeight;
     request.height = height;
-    status = XtMakeGeometryRequest((Widget)nlw, &request, &reply);
+    XtMakeGeometryRequest((Widget)nlw, &request, &reply);
     if(nlw->numeric_list.vsb) XtManageChild(nlw->numeric_list.vsb);
 
     e_format = (char **)XtCalloc(nlw->numeric_list.tuples, sizeof(char *));
@@ -965,19 +955,19 @@ Boolean		fixed_format;
 	    {
 		sprintf(string, e_format[j], 
 			*(nlw->numeric_list.local_vectors[i] + j));
-		fixed_format = False;
+		/*fixed_format = False;*/
 	    }
 	    else
 	    {
 		sprintf(string, f_format[j], 
 			*(nlw->numeric_list.local_vectors[i] + j));
-		fixed_format = True;
+		/*fixed_format = True;*/
 	    }
 	    if (STRLEN(string) > nlw->numeric_list.local_decimal_places[j] + 7)
 	    {
 		sprintf(string, e_format[j], 
 			*(nlw->numeric_list.local_vectors[i] + j));
-		fixed_format = False;
+		/*fixed_format = False;*/
 	    }
 	    
 	    k = 0;
@@ -1055,7 +1045,7 @@ Boolean		fixed_format;
     if(nlw->numeric_list.vsb) XtUnmanageChild(nlw->numeric_list.vsb);
     request.request_mode = CWWidth;
     request.width = width;
-    status = XtMakeGeometryRequest((Widget)nlw, &request, &reply);
+    XtMakeGeometryRequest((Widget)nlw, &request, &reply);
     if(nlw->numeric_list.vsb) XtManageChild(nlw->numeric_list.vsb);
 
     /*
@@ -1082,7 +1072,6 @@ int	n;
 int	value;
 int	blank_lines;
 XmScrolledWindowWidget window;
-XEvent	*event;
 Boolean inverse;
 int	i;
 
@@ -1165,13 +1154,10 @@ Arg	wargs[10];
 int	n;
 int	value;
 int	max;
-int	min;
 int	slider_size;
 int	increment;
 int	page_increment;
-int	blank_lines;
 XmScrolledWindowWidget window;
-XEvent	*event;
 Boolean inverse;
 int	i;
 
@@ -1233,7 +1219,6 @@ int	max;
 int	slider_size;
 int	blank_lines;
 XmScrolledWindowWidget window;
-XEvent	*event;
 Boolean inverse;
 int	i;
 
@@ -1375,7 +1360,7 @@ int		i;
 int		j;
 int		k;
 VectorList	vlist;
-XEvent		*event;
+XEvent		*event=NULL;
 Boolean		do_jump = False;
     
     /* 
@@ -1469,7 +1454,7 @@ Boolean XmNumericListDeleteVector(XmNumericListWidget nlw, int vector_num)
 int		i;
 int		j;
 int		k;
-XEvent		*event;
+XEvent		*event=NULL;
 VectorList	vlist;
     
     /* 
@@ -1554,7 +1539,7 @@ Boolean XmNumericListReplaceSelectedVector(XmNumericListWidget nlw,
 						Vector newvec)
 {
 int		j, vecnum;
-XEvent		*event;
+XEvent		*event=NULL;
     
     /* 
      *  Check that there is a selected item 
